@@ -1,9 +1,10 @@
 # skip if no key ----------------------------------------------------------------------------------------
 
 skip_if_no_auth('meteocat')
+skip_if_no_internet()
 
 # meteocat service options tests ---------------------------------------------------------------------------
-
+withr::local_options(list("keyring_backend" = "env"))
 test_that("meteocat service options works", {
   expected_names <- c("resolution", "start_date", "stations", "api_key")
   expect_type(meteocat_options(api_key = 'tururu'), 'list')
@@ -19,6 +20,7 @@ test_that("meteocat service options works", {
   expect_error(meteocat_options(resolution = 'not_valid_resolution', api_key = 'tururu'), "must be one of")
   expect_error(meteocat_options(), "is missing, with no default")
   expect_error(meteocat_options(stations = 25, api_key = 'tururu'), "must be a character vector")
+  expect_error(meteocat_options(start_date = as.Date('2001-04-25'), api_key = 'tururu'), "'2008-01-01'")
 
 })
 
@@ -35,7 +37,8 @@ test_that("meteocat get info works", {
 test_that("meteocat instant works", {
   # all stations
   api_options <- meteocat_options('instant', api_key = keyring::key_get('meteocat'))
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "temperature",
@@ -62,7 +65,8 @@ test_that("meteocat hourly works", {
   api_options <- meteocat_options(
     'hourly', start_date = as.Date('2021-04-25'), api_key = keyring::key_get('meteocat')
   )
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "temperature",
@@ -77,11 +81,30 @@ test_that("meteocat hourly works", {
   # some stations
   stations_to_check <- test_object[['station_id']][1:3]
   api_options$stations <- stations_to_check
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   main_test_battery(
     test_object, service = 'meteocat', expected_names = expected_names, temperature = temperature,
     stations_to_check = stations_to_check
   )
+
+  # 2008 to 2010 stations lack some variables, check it works without those variables
+  api_options <- meteocat_options(
+    'hourly', start_date = as.Date('2008-04-25'), api_key = keyring::key_get('meteocat')
+  )
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  expected_names <- c(
+    "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
+    "temperature",
+    "relative_humidity", "precipitation",
+    "wind_speed",
+    "global_solar_radiation",
+    "geometry"
+  )
+  main_test_battery(
+    test_object, service = 'meteocat', expected_names = expected_names, temperature = temperature
+  )
 })
 
 test_that("meteocat daily works", {
@@ -89,7 +112,8 @@ test_that("meteocat daily works", {
   api_options <- meteocat_options(
     'daily', start_date = as.Date('2021-04-25'), api_key = keyring::key_get('meteocat')
   )
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "mean_temperature", "min_temperature", 'max_temperature',
@@ -105,11 +129,31 @@ test_that("meteocat daily works", {
   # some stations
   stations_to_check <- test_object[['station_id']][1:3]
   api_options$stations <- stations_to_check
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   main_test_battery(
     test_object, service = 'meteocat', expected_names = expected_names, temperature = mean_temperature,
     stations_to_check = stations_to_check
   )
+
+  # 2008 to 2010 stations lack some variables, check it works without those variables
+  api_options <- meteocat_options(
+    'daily', start_date = as.Date('2008-04-25'), api_key = keyring::key_get('meteocat')
+  )
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  expected_names <- c(
+    "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
+    "mean_temperature", "min_temperature", 'max_temperature',
+    "mean_relative_humidity", "min_relative_humidity",
+    "precipitation",
+    "mean_wind_speed",
+    "global_solar_radiation",
+    "geometry"
+  )
+  main_test_battery(
+    test_object, service = 'meteocat', expected_names = expected_names, temperature = mean_temperature
+  )
 })
 
 test_that("meteocat monthly works", {
@@ -117,7 +161,8 @@ test_that("meteocat monthly works", {
   api_options <- meteocat_options(
     'monthly', start_date = as.Date('2020-04-25'), api_key = keyring::key_get('meteocat')
   )
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "mean_temperature",
@@ -137,7 +182,8 @@ test_that("meteocat monthly works", {
   # some stations
   stations_to_check <- unique(test_object[['station_id']])[1:3]
   api_options$stations <- stations_to_check
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   main_test_battery(
     test_object, service = 'meteocat', expected_names = expected_names, temperature = mean_temperature,
     stations_to_check = stations_to_check
@@ -149,7 +195,8 @@ test_that("meteocat yearly works", {
   api_options <- meteocat_options(
     'yearly', start_date = as.Date('2020-04-25'), api_key = keyring::key_get('meteocat')
   )
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   expected_names <- c(
     "timestamp", "service", "station_id", "station_name", "station_province", "altitude",
     "mean_temperature",
@@ -169,7 +216,8 @@ test_that("meteocat yearly works", {
   # some stations
   stations_to_check <- unique(test_object[['station_id']])[1:3]
   api_options$stations <- stations_to_check
-  expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
+  test_object <- get_meteo_from('meteocat', api_options)
+  # expect_message((test_object <- get_meteo_from('meteocat', api_options)), 'meteo.cat')
   main_test_battery(
     test_object, service = 'meteocat', expected_names = expected_names, temperature = mean_temperature,
     stations_to_check = stations_to_check
@@ -182,11 +230,9 @@ test_that("meteocat API errors, messages, warnings are correctly raised", {
   # invalid key
   api_options <- meteocat_options(api_key = 'tururu')
   expect_error(get_meteo_from('meteocat', api_options), "Invalid API Key")
-  # dates out of bounds
-  api_options <- meteocat_options(
-    'daily', start_date = as.Date('1890-01-01'), api_key = keyring::key_get('meteocat')
-  )
-  expect_error(get_meteo_from('meteocat', api_options), "Unable to obtain data from MeteoCat API:")
+  # dates out of bounds:
+  # This is checked on the service options level
+
   # no data for stations selected
   api_options <- meteocat_options(
     'daily',
@@ -204,7 +250,6 @@ test_that("meteocat API errors, messages, warnings are correctly raised", {
 
 test_that("meteocat get_quota works as expected", {
   api_options <- meteocat_options(api_key = keyring::key_get('meteocat'))
-
   expect_s3_class((test_object <- get_quota_from('meteocat', api_options)), 'tbl')
   expect_named(test_object, c('nom', 'periode', 'maxConsultes', 'consultesRestants', 'consultesRealitzades'))
 })
